@@ -36,7 +36,7 @@
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
-#include <knuminput.h>
+#include <knuminput.h> // kdelibs4support
 
 #include <cmath>
 #include <math.h>
