@@ -33,7 +33,7 @@
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
-#include <knuminput.h>
+#include <knuminput.h> // kdelibs4support
 
 #include "imagelib/effects/kpEffectHSV.h"
 #include "commands/imagelib/effects/kpEffectHSVCommand.h"
@@ -74,14 +74,14 @@ kpEffectHSVWidget::kpEffectHSVWidget (bool actOnSelection, QWidget *parent)
     lay->setColumnStretch (1, 1);
 
 
-    connect (m_hueInput, SIGNAL (valueChanged (double)),
-             this, SIGNAL (settingsChangedDelayed ()));
+    connect (m_hueInput, SIGNAL (valueChanged(double)),
+             this, SIGNAL (settingsChangedDelayed()));
 
-    connect (m_saturationInput, SIGNAL (valueChanged (double)),
-             this, SIGNAL (settingsChangedDelayed ()));
+    connect (m_saturationInput, SIGNAL (valueChanged(double)),
+             this, SIGNAL (settingsChangedDelayed()));
 
-    connect (m_valueInput, SIGNAL (valueChanged (double)),
-             this, SIGNAL (settingsChangedDelayed ()));
+    connect (m_valueInput, SIGNAL (valueChanged(double)),
+             this, SIGNAL (settingsChangedDelayed()));
 }
 
 kpEffectHSVWidget::~kpEffectHSVWidget ()
